==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/mpc/translations/mpc_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="47"/>
        <source>Musepack Plugin</source>
        <translation>Musepack įskiepis</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="49"/>
        <source>Musepack Files</source>
        <translation>Musepack bylos</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="109"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Apie Qmmp Musepack įskiepį</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="110"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack įskiepis</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="111"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bylos dydis</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-0.5.2.tar.bz2: qmmp-0.5.2/src/plugins/Input/mpc/translations/mpc_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="47"/>
        <source>Musepack Plugin</source>
        <translation>Musepack įskiepis</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="49"/>
        <source>Musepack Files</source>
        <translation>Musepack bylos</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="109"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Apie Qmmp Musepack įskiepį</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="110"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack įskiepis</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bylos dydis</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
